Plover MIDI
===========

Add support for MIDI keyboards/machines to `Plover <http://www.openstenoproject.org/>`_.

This include support for the Italian `Michela Machine <https://it.wikipedia.org/wiki/Macchina_Michela>`_:

.. image:: https://upload.wikimedia.org/wikipedia/commons/thumb/f/fb/Michela_MIDI.jpg/220px-Michela_MIDI.jpg
